@@ -27,6 +27,7 @@
 #include "prefs.h"
 #include "ui.h"
 #include "util.h"
+#include <gdk/gdk.h>
 #include <gio/gio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -1097,7 +1098,10 @@ meta_prefs_get_cursor_theme (void)
 int
 meta_prefs_get_cursor_size (void)
 {
-  return cursor_size;
+  GdkWindow *window = gdk_get_default_root_window ();
+  gint scale = gdk_window_get_scale_factor (window);
+
+  return cursor_size * scale;
 }
 
 gboolean
