@@ -179,6 +179,8 @@ typedef enum _MetaKeyBindingAction
   META_KEYBINDING_ACTION_SWITCH_GROUP_BACKWARD,
   META_KEYBINDING_ACTION_SWITCH_WINDOWS,
   META_KEYBINDING_ACTION_SWITCH_WINDOWS_BACKWARD,
+  META_KEYBINDING_ACTION_SWITCH_WINDOWS_ALL,
+  META_KEYBINDING_ACTION_SWITCH_WINDOWS_ALL_BACKWARD,
   META_KEYBINDING_ACTION_SWITCH_PANELS,
   META_KEYBINDING_ACTION_SWITCH_PANELS_BACKWARD,
   META_KEYBINDING_ACTION_CYCLE_GROUP,
