@@ -559,8 +559,6 @@ make_dock (int type)
   GtkWidget *image;
   GtkWidget *box;
   GtkWidget *button;
-  int        sc_width;
-  int        sc_height;
 
   g_return_if_fail (type != DOCK_ALL);
 
@@ -595,9 +593,6 @@ make_dock (int type)
 
   gtk_container_add (GTK_CONTAINER (window), box);
 
-  gdk_window_get_geometry (gdk_screen_get_root_window (gdk_screen_get_default()),
-                           NULL, NULL, &sc_width, &sc_height);
-
 #define DOCK_SIZE 48
   switch (type)
     {
@@ -609,7 +604,7 @@ make_dock (int type)
       break;
     case DOCK_RIGHT:
       gtk_widget_set_size_request (window, DOCK_SIZE, 400);
-      gtk_window_move (GTK_WINDOW (window), sc_width - DOCK_SIZE, 200);
+      gtk_window_move (GTK_WINDOW (window), WidthOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())) - DOCK_SIZE, 200);
       set_gtk_window_struts (window, 0, DOCK_SIZE, 0, 0);
       gtk_window_set_title (GTK_WINDOW (window), "RightDock");
       break;
@@ -621,7 +616,7 @@ make_dock (int type)
       break;
     case DOCK_BOTTOM:
       gtk_widget_set_size_request (window, 600, DOCK_SIZE);
-      gtk_window_move (GTK_WINDOW (window), 200, sc_height - DOCK_SIZE);
+      gtk_window_move (GTK_WINDOW (window), 200, HeightOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())) - DOCK_SIZE);
       set_gtk_window_struts (window, 0, 0, 0, DOCK_SIZE);
       gtk_window_set_title (GTK_WINDOW (window), "BottomDock");
       break;
@@ -668,7 +663,6 @@ dock_cb (GSimpleAction *action,
     }
 }
 
-#if GTK_CHECK_VERSION (3, 16, 0)
 static void
 override_background_color (GtkWidget *widget,
                            GdkRGBA   *rgba)
@@ -688,7 +682,6 @@ override_background_color (GtkWidget *widget,
                                   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
   g_object_unref (provider);
 }
-#endif
 
 static void
 desktop_cb (GSimpleAction *action,
@@ -698,16 +691,13 @@ desktop_cb (GSimpleAction *action,
   GtkWidget *window;
   GtkWidget *label;
   GdkRGBA    desktop_color;
-  int        sc_width;
-  int        sc_height;
-
-  gdk_window_get_geometry (gdk_screen_get_root_window (gdk_screen_get_default()),
-                           NULL, NULL, &sc_width, &sc_height);
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   set_gtk_window_type (GTK_WINDOW (window), "_NET_WM_WINDOW_TYPE_DESKTOP");
   gtk_window_set_title (GTK_WINDOW (window), "Desktop");
-  gtk_widget_set_size_request (window, sc_width, sc_height);
+  gtk_widget_set_size_request (window,
+                               WidthOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())),
+                               HeightOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())));
   gtk_window_move (GTK_WINDOW (window), 0, 0);
 
   desktop_color.red = 0.32;
@@ -715,11 +705,7 @@ desktop_cb (GSimpleAction *action,
   desktop_color.blue = 0.65;
   desktop_color.alpha = 1.0;
 
-#if GTK_CHECK_VERSION (3, 16, 0)
   override_background_color (window, &desktop_color);
-#else
-  gtk_widget_override_background_color (window, 0, &desktop_color);
-#endif
 
   label = focus_label (window);
 
